@@ -22,6 +22,7 @@ import appdirs
 
 from ansys.mapdl import core as pymapdl
 from ansys.mapdl.core import LOG
+from ansys.mapdl.core._version import SUPPORTED_ANSYS_VERSIONS
 from ansys.mapdl.core.errors import LockFileException, MapdlDidNotStart, VersionError
 from ansys.mapdl.core.licensing import ALLOWABLE_LICENSES, LicenseChecker
 from ansys.mapdl.core.mapdl import _MapdlCore
@@ -618,18 +619,25 @@ def get_start_instance(start_instance_default=True):
 
 
 def _get_available_base_ansys():
-    """Return a dictionary of available ANSYS versions with their base paths.
+    """Return a dictionary of available Ansys versions with their base paths.
+
+    Notes
+    -----
+
+    On Windows, It uses the environment variable ``AWP_ROOTXXX``.
+
+    The student versions are returned at the end of the dict and with negative value for the version.
 
     Returns
     -------
-    Return all installed ANSYS paths in Windows
+    Return all installed Ansys paths in Windows.
 
     >>> _get_available_base_ansys()
-    {194: 'C:\\Program Files\\ANSYS INC\\v194',
-     202: 'C:\\Program Files\\ANSYS INC\\v202',
-     211: 'C:\\Program Files\\ANSYS INC\\v211'}
+    {222: 'C:\\Program Files\\ANSYS Inc\\v222',
+     212: 'C:\\Program Files\\ANSYS Inc\\v212',
+     -222: 'C:\\Program Files\\ANSYS Inc\\ANSYS Student\\v222'}
 
-    Within Linux
+    Return all installed Ansys paths in Linux.
 
     >>> _get_available_base_ansys()
     {194: '/usr/ansys_inc/v194',
@@ -637,23 +645,47 @@ def _get_available_base_ansys():
      211: '/usr/ansys_inc/v211'}
     """
     base_path = None
-    if os.name == "nt":
-        supported_versions = [194, 202, 211, 212, 221]
-        awp_roots = {
-            ver: os.environ.get(f"AWP_ROOT{ver}", "") for ver in supported_versions
-        }
+    if os.name == "nt":  # pragma: no cover
+        supported_versions = SUPPORTED_ANSYS_VERSIONS
+        # The student version overwrites the AWP_ROOT env var (if it is installed later)
+        # However the priority should be given to the non-student version.
+        awp_roots = []
+        awp_roots_student = []
+
+        for ver in supported_versions:
+            path_ = os.environ.get(f"AWP_ROOT{ver}", "")
+            path_non_student = path_.replace("\\ANSYS Student", "")
+
+            if "student" in path_.lower() and os.path.exists(path_non_student):
+                # Check if also exist a non-student version
+                awp_roots.append([ver, path_non_student])
+                awp_roots_student.insert(0, [-1 * ver, path_])
+
+            else:
+                awp_roots.append([ver, path_])
+
+        awp_roots.extend(awp_roots_student)
         installed_versions = {
-            ver: path for ver, path in awp_roots.items() if path and os.path.isdir(path)
+            ver: path for ver, path in awp_roots if path and os.path.isdir(path)
         }
+
         if installed_versions:
             return installed_versions
-        else:
+        else:  # pragma: no cover
+            LOG.debug(
+                "No installed ANSYS found using 'AWP_ROOT' environments. Let's suppose a base path."
+            )
             base_path = os.path.join(os.environ["PROGRAMFILES"], "ANSYS INC")
+            if not os.path.exists(base_path):
+                LOG.debug(
+                    f"The supposed 'base_path'{base_path} does not exist. No available ansys found."
+                )
+                return {}
     elif os.name == "posix":
         for path in ["/usr/ansys_inc", "/ansys_inc"]:
             if os.path.isdir(path):
                 base_path = path
-    else:
+    else:  # pragma: no cover
         raise OSError(f"Unsupported OS {os.name}")
 
     if base_path is None:
@@ -661,6 +693,10 @@ def _get_available_base_ansys():
 
     paths = glob(os.path.join(base_path, "v*"))
 
+    # Testing for ANSYS STUDENT version
+    if not paths:  # pragma: no cover
+        paths = glob(os.path.join(base_path, "ANSYS*"))
+
     if not paths:
         return {}
 
@@ -673,6 +709,35 @@ def _get_available_base_ansys():
     return ansys_paths
 
 
+def get_available_ansys_installations():
+    """Return a dictionary of available Ansys versions with their base paths.
+
+    Notes
+    -----
+
+    On Windows, It uses the environment variable ``AWP_ROOTXXX``.
+
+    The student versions are returned at the end of the dict and with negative value for the version.
+
+    Returns
+    -------
+    Return all installed Ansys paths in Windows.
+
+    >>> get_available_ansys_installations()
+    {222: 'C:\\Program Files\\ANSYS Inc\\v222',
+     212: 'C:\\Program Files\\ANSYS Inc\\v212',
+     -222: 'C:\\Program Files\\ANSYS Inc\\ANSYS Student\\v222'}
+
+    Return all installed Ansys paths in Linux.
+
+    >>> get_available_ansys_installations()
+    {194: '/usr/ansys_inc/v194',
+     202: '/usr/ansys_inc/v202',
+     211: '/usr/ansys_inc/v211'}
+    """
+    return _get_available_base_ansys()
+
+
 def find_ansys():
     """Searches for ansys path within the standard install location
     and returns the path of the latest version.
@@ -703,6 +768,7 @@ def find_ansys():
         return "", ""
     version = max(versions.keys())
     ans_path = versions[version]
+    version = abs(version)
     if os.name == "nt":
         ansys_bin = os.path.join(
             ans_path, "ansys", "bin", "winx64", f"ansys{version}.exe"
@@ -773,11 +839,12 @@ def change_default_ansys_path(exe_loc):
 
 
 def save_ansys_path(exe_loc=None):  # pragma: no cover
-    """Find ANSYS path or query user.
+    """Find MAPDL's path or query user.
 
     If no ``exe_loc`` argument is supplied, this function attempt
     to obtain the MAPDL executable from (and in order):
-    - The default ansys paths (i.e. 'C:/Program Files/Ansys Inc/vXXX/ansys/bin/ansysXXX')
+
+    - The default ansys paths (i.e. ``'C:/Program Files/Ansys Inc/vXXX/ansys/bin/ansysXXX'``)
     - The configuration file
     - User input
 
@@ -787,7 +854,7 @@ def save_ansys_path(exe_loc=None):  # pragma: no cover
     Parameters
     ----------
     exe_loc : str, optional
-        Path of the MAPDL executable ('ansysXXX'), by default None
+        Path of the MAPDL executable ('ansysXXX'), by default ``None``.
 
     Returns
     -------
@@ -804,15 +871,15 @@ def save_ansys_path(exe_loc=None):  # pragma: no cover
         >>> import appdirs
         >>> import os
         >>> print(os.path.join(appdirs.user_data_dir("ansys_mapdl_core"), "config.txt"))
-        C:/Users/gayuso/AppData/Local/ansys_mapdl_core/ansys_mapdl_core/config.txt
+        C:/Users/user/AppData/Local/ansys_mapdl_core/ansys_mapdl_core/config.txt
 
+    Examples
+    --------
     You can change the default ``exe_loc`` either by modifying the mentioned
-    ``config.txt`` file or by executing this function:
+    ``config.txt`` file or by executing:
 
-    .. code:: python
-
-       >>> from ansys.mapdl.core.launcher import save_ansys_path
-       >>> save_ansys_path('/new/path/to/executable')
+    >>> from ansys.mapdl.core import save_ansys_path
+    >>> save_ansys_path('/new/path/to/executable')
 
     """
     if exe_loc is None:
@@ -982,6 +1049,7 @@ def launch_mapdl(
     ip=None,
     clear_on_connect=True,
     log_apdl=None,
+    remove_temp_files=False,
     verbose_mapdl=False,
     license_server_check=True,
     license_type=None,
@@ -1095,7 +1163,11 @@ def launch_mapdl(
         ``log_apdl='pymapdl_log.txt'``). By default this is disabled.
 
     remove_temp_files : bool, optional
-        Removes temporary files on exit.  Default ``False``.
+        When ``run_location`` is ``None``, this launcher creates a new MAPDL
+        working directory within the user temporary directory, obtainable with
+        ``tempfile.gettempdir()``. When this parameter is
+        ``True``, this directory will be deleted when MAPDL is exited. Default
+        ``False``.
 
     verbose_mapdl : bool, optional
         Enable printing of all output when launching and running
@@ -1385,6 +1457,9 @@ def launch_mapdl(
     else:
         if not os.path.isdir(run_location):
             raise FileNotFoundError(f'"{run_location}" is not a valid directory')
+        if remove_temp_files:
+            LOG.info("`run_location` set. Disabling the removal of temporary files.")
+            remove_temp_files = False
 
     # verify no lock file and the mode is valid
     check_lock_file(run_location, jobname, override)
@@ -1485,10 +1560,10 @@ def launch_mapdl(
             mapdl = MapdlConsole(loglevel=loglevel, log_apdl=log_apdl, **start_parm)
         elif mode == "corba":
             try:
-                # pending deprication to ansys-mapdl-corba
+                # pending deprecation to ansys-mapdl-corba
                 from ansys.mapdl.core.mapdl_corba import MapdlCorba
-            except ImportError:
-                raise ImportError(
+            except ModuleNotFoundError:  # pragma: no cover
+                raise ModuleNotFoundError(
                     "To use this feature, install the MAPDL CORBA package"
                     " with:\n\npip install ansys_corba"
                 ) from None
@@ -1516,7 +1591,7 @@ def launch_mapdl(
                 cleanup_on_exit=cleanup_on_exit,
                 loglevel=loglevel,
                 set_no_abort=set_no_abort,
-                remove_temp_files=kwargs.pop("remove_temp_files", False),
+                remove_temp_files=remove_temp_files,
                 log_apdl=log_apdl,
                 **start_parm,
             )
